@@ -1,29 +1,15 @@
 /*
- *  soldevicetypes.h
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #ifndef SOLDEVICETYPES
 #define SOLDEVICETYPES
 
-#include "soldevice.h"
 #include "infopanel.h"
+#include "soldevice.h"
 
 class QVListLayout;
 
@@ -48,8 +34,7 @@ public:
     };
 
     SolStorageDevice(const Solid::DeviceInterface::Type &);
-    SolStorageDevice(QTreeWidgetItem *, const Solid::Device &,
-                     const storageChildren & = CREATECHILDREN);
+    SolStorageDevice(QTreeWidgetItem *, const Solid::Device &, const storageChildren & = CREATECHILDREN);
     QVListLayout *infoPanelLayout() override;
 
 private:
